@@ -1,8 +1,10 @@
-# -*- coding: utf-8 -*-
+"""Utility functions for cltoolbox."""
+
+
 def purify_kwargs(kwargs):
     """If type or metavar are set to None, they are removed from kwargs."""
     for key, value in kwargs.copy().items():
-        if key in ["type", "metavar"] and value is None:
+        if key in ("type", "metavar") and value is None:
             del kwargs[key]
     return kwargs
 
@@ -11,15 +13,15 @@ def action_by_type(obj):
     """Determine an action and a type for the given object if possible."""
     if isinstance(obj, bool):
         return {"action": ["store_true", "store_false"][obj]}
-    kw = {"action": "append"} if isinstance(obj, list) else {}
-    kw.update(get_type(obj))
-    return kw
+    kwd = {"action": "append"} if isinstance(obj, list) else {}
+    kwd.update(get_type(obj))
+    return kwd
 
 
 def get_type(obj):
     """Determine the type of the object if among some of the built-in ones."""
     otype = type(obj)
-    if any(otype is t for t in {int, float, str, bool}):
+    if any(otype is t for t in (int, float, str, bool)):
         return {"type": otype}
     return {}
 
